@@ -21,16 +21,23 @@ def from_websafe(data):
     return data + "=="[: (3 * len(data)) % 4]
 
 
-def enter_bootloader_or_die(p):
-    try:
-        p.enter_solo_bootloader()
-    # except OSError:
-    #     pass
-    except CtapError as e:
-        if e.code == CtapError.ERR.INVALID_COMMAND:
-            print(
-                "Solo appears to not be a solo hacker.  Try holding down the button for 2 while you plug token in."
-            )
-            sys.exit(1)
-        else:
-            raise (e)
+class Timeout(object):
+    """Utility class for adding a timeout to an event.
+    :param time_or_event: A number, in seconds, or a threading.Event object.
+    :ivar event: The Event associated with the Timeout.
+    :ivar timer: The Timer associated with the Timeout, if any.
+    """
+
+    def __init__(self, time):
+        self.event = time
+        self.timer = None
+
+    def __enter__(self):
+        if self.timer:
+            self.timer.start()
+        return self.event
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        if self.timer:
+            self.timer.cancel()
+            self.timer.join()
